@@ -684,6 +684,30 @@ class String(unicode, _Value):
         """Return quoted XML representation of the attribute value"""
         return saxutils.quoteattr(self)
 
+class NonEmptyString(String):
+
+    """A String that is forced to have contents
+
+    Normally, _Value objects refuse to instantiate when
+    the value held is blank - such as a string of spaces.
+
+    This class always produces a string.
+    When there are no contents, make a single space.
+
+    """
+
+    BLANK = " "
+
+    @classmethod
+    def fromValue(cls, value):
+        """Return new object of this class"""
+        # REQUIRED must be allowed for class initialization
+        if not value:
+            return cls.BLANK
+        if isinstance(value, basestring) and (value.strip() == ""):
+            return cls.BLANK
+        return super(NonEmptyString, cls).fromValue(value)
+
 class Expression(String):
 
     # pylint: disable-msg=R0904
@@ -1409,6 +1433,12 @@ class Box(object):
         ("float", False),
     )
 
+    # 03-feb-2018 The dimensions take about 13% of the total memory
+    # consumption by the builder, and Box objects take about 30%.
+    # Tried putting x, y, width, and height to an array();
+    # got 25% relative gain of total size of Box objects,
+    # but cumulative size of the arrays is 3x bigger than Dimensions,
+    # which made 20% loss in the whole.
     __slots__ = map(lambda x: x[0], DEFAULTS)
 
     # dimensions must be rounded after each calculation.
